@@ -1,4 +1,6 @@
+import collections
 import datetime
+import functools
 from urllib.parse import urlparse
 import uuid
 
@@ -6,7 +8,7 @@ import yaml
 
 from .ecr import Ecr
 from .ecs import Ecs
-
+from .exceptions import ConfigError
 from .releases_store import DynamoDbReleaseStore
 from .iam import Iam
 from .tags import parse_aws_tags
@@ -39,7 +41,7 @@ class Projects:
         try:
             config = self.projects[project_id]
         except KeyError:
-            raise RuntimeError(f"No matching project {project_id} in {self.projects}")
+            raise ConfigError(f"No matching project {project_id} in {self.projects}")
 
         return Project(project_id=project_id, config=config, **kwargs)
 
@@ -61,7 +63,7 @@ class Project:
             self.config['role_arn'] = role_arn
         else:
             if 'role_arn' not in self.config:
-                raise ValueError("region_name is not set!")
+                raise ConfigError("role_arn is not set!")
 
         if region_name:
             self.config['region_name'] = region_name
@@ -111,6 +113,7 @@ class Project:
             role_arn=role_arn or self.role_arn
         )
 
+    @functools.lru_cache()
     def _ecs(self, region_name=None, role_arn=None):
         return Ecs(
             region_name=region_name or self.region_name,
@@ -181,6 +184,50 @@ class Project:
         else:
             return self.releases_store.get_release(release_id)
 
+    def _get_services_by_image_id(self, release):
+        """
+        Generates a set of tuples (image_id, List[services])
+        """
+        for image_id, _ in release["images"].items():
+            # TODO: self.image_repositories should be a dict, not a list
+            matched_image = self._match_image_id(image_id)
+
+            # TODO: Should this ever happen?
+            if matched_image is None:
+                continue
+
+            try:
+                services = matched_image["services"]
+            except KeyError:
+                continue
+
+            yield (image_id, services)
+
+    def get_ecs_service_arns(self, release, environment_id):
+        """
+        Returns a dict (image ID) -> List[service ARNs].
+        """
+        result = collections.defaultdict(list)
+
+        for image_id, services in self._get_services_by_image_id(release):
+            for serv in services:
+                ecs = self._ecs(
+                    region_name=serv.get('region_name'),
+                    role_arn=serv.get('role_arn')
+                )
+
+                matching_service = ecs.find_matching_service(
+                    service_id=serv["id"],
+                    environment_id=environment_id
+                )
+
+                try:
+                    result[image_id].append(matching_service["serviceArn"])
+                except TypeError:
+                    assert matching_service is None, matching_service
+
+        return dict(result)
+
     def get_ecs_services(self, release, environment_id):
         def _get_service(service):
             ecs = self._ecs(
